# Dialtone

[![PyPI](https://img.shields.io/pypi/v/dialtone_python.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/dialtone_python.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/dialtone_python)][pypi status]
[![License](https://img.shields.io/pypi/l/dialtone_python)][license]

[![Read the documentation at https://dialtone_python.readthedocs.io/](https://img.shields.io/readthedocs/dialtone_python/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/getwellspring/dialtone_python/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/getwellspring/dialtone_python/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/dialtone/
[read the docs]: https://dialtone_python.readthedocs.io/
[tests]: https://github.com/getwellspring/dialtone_python/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/getwellspring/dialtone_python
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

## Installation

You can install _Dialtone_ via [pip] from [PyPI]:

```console
$ pip install dialtone
```

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
_Dialtone_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

[pypi]: https://pypi.org/
[file an issue]: https://github.com/getwellspring/dialtone_python/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/getwellspring/dialtone_python/blob/main/LICENSE
[contributor guide]: https://github.com/getwellspring/dialtone_python/blob/main/CONTRIBUTING.md
[command-line reference]: https://dialtone_python.readthedocs.io/en/latest/usage.html
